==> haskell-type-hint-0.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: type-hint
version: 0.1
id: type-hint-0.1-DezARUeVP6w2gAn4JgNfUm
key: type-hint-0.1-DezARUeVP6w2gAn4JgNfUm
license: BSD3
copyright: 2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/type-hint
synopsis: Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.
category: Phantom Types
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Type.Hint
abi: bcd0f2b2a7c97a1ebfc22c4252e83c03
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/type-hint-0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/type-hint-0.1
hs-libraries: HStype-hint-0.1-DezARUeVP6w2gAn4JgNfUm
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html: /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-hint-0.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: type-hint
version: 0.1
id: type-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
key: type-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
license: BSD-3-Clause
copyright: 2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/type-hint
synopsis: Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.
category: Phantom Types
abi: 602b82e702502c1ae74d778e5643acb7
exposed: True
exposed-modules:
    Type.Hint
import-dirs: /usr/lib/ghc-8.4.2/site-local/type-hint-0.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/type-hint-0.1
hs-libraries: HStype-hint-0.1-BZHH0UJkhgC2RXAa9JWu8V
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html: /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
